@@ -54,7 +54,7 @@
  * 
  */
 
-#include <config.h> 
+#include "config.h"
 
 #ifdef HAVE_LIBXDMCP
 #include <stdio.h>
@@ -286,12 +286,12 @@ gdm_xdmcp_displays_from_host (struct sockaddr_in *addr)
 #ifdef ENABLE_IPV6
 		    if (disp->addrtype == AF_INET6 &&
 			memcmp (&disp->addr6, &((struct sockaddr_in6 *)addr)->sin6_addr, sizeof (struct in6_addr)) == 0)
-			count ++;
+			count++;
 		    else
 #endif
 		    if (disp->addrtype == AF_INET &&
 		    memcmp (&disp->addr, &((struct sockaddr_in *)addr)->sin_addr, sizeof (struct in_addr)) == 0)
-			count ++;
+			count++;
 		}
 	}
 
@@ -1142,6 +1142,7 @@ gdm_xdmcp_handle_forward_query (struct sockaddr_in *clnt_sa, gint len)
 
 	if (clnt_port.length == 2 &&
 	       clnt_addr.length == 4) {
+		char * ipv4_addr;
 
 		/* Convert IPv4 address to IPv6 if needed */
 		struct sockaddr_in tmp_disp_sa = {0};
@@ -1149,7 +1150,7 @@ gdm_xdmcp_handle_forward_query (struct sockaddr_in *clnt_sa, gint len)
 		memcpy (&((struct sockaddr_in *)(&tmp_disp_sa))->sin_port, clnt_port.data, 2);
 		memcpy (&((struct sockaddr_in *)(&tmp_disp_sa))->sin_addr.s_addr, clnt_addr.data, 4);
 
-		char * ipv4_addr = inet_ntoa (((struct sockaddr_in *)(&tmp_disp_sa))->sin_addr);
+		ipv4_addr = inet_ntoa (((struct sockaddr_in *)(&tmp_disp_sa))->sin_addr);
 		strcpy (buffer6, "::ffff:");
 		strncat (buffer6, ipv4_addr, INET_ADDRSTRLEN);
 
@@ -1445,7 +1446,7 @@ managed_forward_handler (gpointer data)
 	if (gdm_xdmcpfd > 0)
 		gdm_xdmcp_really_send_managed_forward (&(mf->manager),
 						       &(mf->origin));
-	mf->times ++;
+	mf->times++;
 	if (gdm_xdmcpfd <= 0 || mf->times >= 2) {
 		managed_forwards = g_slist_remove (managed_forwards, mf);
 		mf->handler = 0;
