@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,8 @@ gboolean	gdm_xdmcp_init	(void);
 void		gdm_xdmcp_run	(void);
 void		gdm_xdmcp_close	(void);
 
+void gdm_xdmcp_migrate (GdmDisplay *from, GdmDisplay *to);
+
 #ifdef HAVE_LIBXDMCP
 /* Fix broken X includes */
 int XdmcpReallocARRAY8 (ARRAY8Ptr array, int length);
