@@ -26,17 +26,21 @@
 #include <X11/X.h>
 #include <X11/Xlib.h>
 
-/* login window will be given focus every time a window
- * is killed */
+/*
+ * Login window will be given focus every time a window
+ * is killed
+ */
 void	gdm_wm_init			(Window login_window);
 
-/* By default new windows aren't given focus, you have to
- * call this function with a TRUE */
+/*
+ * By default new windows aren't given focus, you have to
+ * call this function with a TRUE
+ */
 void	gdm_wm_focus_new_windows	(gboolean focus);
 
 void	gdm_wm_focus_window		(Window window);
 
-/* movement for the impatient */
+/* Movement for the impatient */
 void	gdm_wm_move_window_now		(Window window,
 					 int x,
 					 int y);
@@ -44,7 +48,7 @@ void	gdm_wm_get_window_pos		(Window window,
 					 int *xp,
 					 int *yp);
 
-/* refuse to focus the login window, poor mans modal dialogs */
+/* Refuse to focus the login window, poor mans modal dialogs */
 void	gdm_wm_no_login_focus_push	(void);
 void	gdm_wm_no_login_focus_pop	(void);
 
@@ -54,21 +58,40 @@ void	gdm_wm_no_login_focus_pop	(void);
 void	gdm_wm_screen_init		(int cur_screen_num);
 void	gdm_wm_set_screen		(int cur_screen_num);
 
-/* Not really a WM function, center a gtk window on current screen
- * by setting uposition */
+/*
+ * Not really a WM function, center a gtk window on current screen
+ * by setting uposition
+ */
 void	gdm_wm_center_window		(GtkWindow *cw);
 
-/* Save and restore stacking order, useful for restarting
- * the greeter */
+/*
+ * Save and restore stacking order, useful for restarting
+ * the greeter
+ */
 void	gdm_wm_save_wm_order		(void);
 void	gdm_wm_restore_wm_order		(void);
 
-/* access to the screen structures */
+/* Dialogs */
+gint    gdm_wm_query_dialog             (const gchar *primary_message,
+                                         const gchar *secondary_message,
+                                         const char *posbutton,
+                                         const char *negbutton,
+                                         gboolean has_cancel);
+gint    gdm_wm_warn_dialog              (const gchar *primary_message,
+                                         const gchar *secondary_message,
+                                         const char *posbutton,
+                                         const char *negbutton,
+                                         gboolean has_cancel);
+void    gdm_wm_show_info_msg_dialog     (const gchar *msg_file,
+                                         const gchar *msg_font);
+void    gdm_wm_message_dialog           (const gchar *primary_message,
+                                         const gchar *secondary_message);
+
+/* Access to the screen structures */
 extern GdkRectangle *gdm_wm_allscreens;
 extern int gdm_wm_screens;
 extern GdkRectangle gdm_wm_screen;
 
-
 #endif /* GDM_WM_H */
 
 /* EOF */
