@@ -53,7 +53,7 @@ ve_find_file (const char *filename, const GList *directories)
 	path = g_getenv ("GNOME_PATH");
 	if (path != NULL) {
 		pathv = g_strsplit (path, ":", 0);
-		for (i = 0; pathv != NULL && pathv[i] != NULL; i++) {
+		for (i = 0; pathv[i] != NULL; i++) {
 			s = g_build_filename (pathv[i], "share", filename, NULL);
 			if (g_access (s, F_OK) == 0) {
 				g_strfreev (pathv);
